@@ -11,6 +11,7 @@ A simple example to execute a command:
 
 .. code-block:: yaml
 
+    # Store the current date in a file
     date > /tmp/salt-run:
       cmd.run
 
@@ -110,13 +111,13 @@ a simple protocol described below:
            - stateful: True
 
        Run only if myscript changed something:
-         cmd.wait:
+         cmd.run:
            - name: echo hello
            - cwd: /
-           - watch:
+           - onchanges:
                - cmd: Run myscript
 
-   Note that if the ``cmd.wait`` state also specifies ``stateful: True`` it can
+   Note that if the second ``cmd.run`` state also specifies ``stateful: True`` it can
    then be watched by some other states as well.
 
 4. :strong:`The stateful argument can optionally include a test_name parameter.`
@@ -144,27 +145,15 @@ a simple protocol described below:
            - stateful:
              - test_name: masterscript test
 
-``cmd.wait`` is not restricted to watching only cmd states. For example
-it can also watch a git state for changes
-
-.. code-block:: yaml
-
-    # Watch for changes to a git repo and rebuild the project on updates
-    my-project:
-      git.latest:
-        - name: git@github.com/repo/foo
-        - target: /opt/foo
-        - rev: master
-      cmd.wait:
-        - name: make install
-        - cwd: /opt/foo
-        - watch:
-          - git: my-project
-
 
 Should I use :mod:`cmd.run <salt.states.cmd.run>` or :mod:`cmd.wait <salt.states.cmd.wait>`?
 --------------------------------------------------------------------------------------------
 
+.. note::
+
+    Use ``cmd.run`` together with :mod:`onchanges </ref/states/requisites#onchanges>`
+    instead of ``cmd.wait``.
+
 These two states are often confused. The important thing to remember about them
 is that :mod:`cmd.run <salt.states.cmd.run>` states are run each time the SLS
 file that contains them is applied. If it is more desirable to have a command
@@ -187,6 +176,27 @@ executed when the state it is watching changes. Example:
         - require:
           - file: /usr/local/bin/postinstall.sh
 
+``cmd.wait`` itself does not do anything; all functionality is inside its ``mod_watch``
+function, which is called by ``watch`` on changes.
+
+``cmd.wait`` will be deprecated in future due to the confusion it causes. The
+preferred format is using the :doc:`onchanges Requisite </ref/states/requisites>`, which
+works on ``cmd.run`` as well as on any other state. The example would then look as follows:
+
+.. code-block:: yaml
+
+    /usr/local/bin/postinstall.sh:
+      cmd.run:
+        - onchanges:
+          - pkg: mycustompkg
+      file.managed:
+        - source: salt://utils/scripts/postinstall.sh
+
+    mycustompkg:
+      pkg.installed:
+        - require:
+          - file: /usr/local/bin/postinstall.sh
+
 How do I create an environment from a pillar map?
 -------------------------------------------------
 
@@ -207,20 +217,11 @@ To use it one must convert it to a list. Example:
 # Import python libs
 from __future__ import absolute_import
 
-# Windows platform has no 'grp' module
 import os
 import copy
 import json
-import shlex
 import logging
 
-HAS_GRP = False
-try:
-    import grp
-    HAS_GRP = True
-except ImportError:
-    pass
-
 # Import salt libs
 import salt.utils
 from salt.exceptions import CommandExecutionError, SaltRenderError
@@ -258,7 +259,7 @@ def _reinterpreted_state(state):
             out = out[idx + 1:]
         data = {}
         try:
-            for item in shlex.split(out):
+            for item in salt.utils.shlex_split(out):
                 key, val = item.split('=')
                 data[key] = val
         except ValueError:
@@ -305,11 +306,10 @@ def _is_true(val):
     raise ValueError('Failed parsing boolean value: {0}'.format(val))
 
 
-def mod_run_check(cmd_kwargs, onlyif, unless, group, creates):
+def mod_run_check(cmd_kwargs, onlyif, unless, creates):
     '''
     Execute the onlyif and unless logic.
     Return a result dict if:
-    * group is not available
     * onlyif failed (onlyif != 0)
     * unless succeeded (unless == 0)
     else return True
@@ -318,14 +318,6 @@ def mod_run_check(cmd_kwargs, onlyif, unless, group, creates):
     # to quote problems
     cmd_kwargs = copy.deepcopy(cmd_kwargs)
     cmd_kwargs['use_vt'] = False
-    if group and HAS_GRP:
-        try:
-            egid = grp.getgrnam(group).gr_gid
-            if not __opts__['test']:
-                os.setegid(egid)
-        except KeyError:
-            return {'comment': 'The group {0} is not available'.format(group),
-                    'result': False}
 
     if onlyif is not None:
         if isinstance(onlyif, string_types):
@@ -392,8 +384,7 @@ def wait(name,
          unless=None,
          creates=None,
          cwd=None,
-         user=None,
-         group=None,
+         runas=None,
          shell=None,
          env=(),
          stateful=False,
@@ -402,7 +393,11 @@ def wait(name,
          use_vt=False,
          **kwargs):
     '''
-    Run the given command only if the watch statement calls it
+    Run the given command only if the watch statement calls it.
+
+    .. note::
+
+        Use :mod:`cmd.run <salt.states.cmd.run>` with :mod:`onchange </ref/states/requisites#onchanges>` instead.
 
     name
         The command to execute, remember that the command will execute with the
@@ -420,12 +415,9 @@ def wait(name,
         The current working directory to execute the command in, defaults to
         /root
 
-    user
+    runas
         The user name to run the command as
 
-    group
-        The group context to run the command as
-
     shell
         The shell to use for execution, defaults to /bin/sh
 
@@ -492,6 +484,16 @@ def wait(name,
         interactively to the console and the logs.
         This is experimental.
     '''
+    if 'user' in kwargs or 'group' in kwargs:
+        salt.utils.warn_until(
+            'Oxygen',
+            'The legacy user/group arguments are deprecated. '
+            'Replace them with runas. '
+            'These arguments will be removed in Salt Oxygen.'
+        )
+        if 'user' in kwargs and kwargs['user'] is not None and runas is None:
+            runas = kwargs.pop('user')
+
     # Ignoring our arguments is intentional.
     return {'name': name,
             'changes': {},
@@ -509,8 +511,7 @@ def wait_script(name,
                 onlyif=None,
                 unless=None,
                 cwd=None,
-                user=None,
-                group=None,
+                runas=None,
                 shell=None,
                 env=None,
                 stateful=False,
@@ -549,12 +550,9 @@ def wait_script(name,
         The current working directory to execute the command in, defaults to
         /root
 
-    user
+    runas
         The user name to run the command as
 
-    group
-        The group context to run the command as
-
     shell
         The shell to use for execution, defaults to the shell grain
 
@@ -617,6 +615,16 @@ def wait_script(name,
         regardless, unless ``quiet`` is used for this value.
 
     '''
+    if 'user' in kwargs or 'group' in kwargs:
+        salt.utils.warn_until(
+            'Oxygen',
+            'The legacy user/group arguments are deprecated. '
+            'Replace them with runas. '
+            'These arguments will be removed in Salt Oxygen.'
+        )
+        if 'user' in kwargs and kwargs['user'] is not None and runas is None:
+            runas = kwargs.pop('user')
+
     # Ignoring our arguments is intentional.
     return {'name': name,
             'changes': {},
@@ -629,8 +637,7 @@ def run(name,
         unless=None,
         creates=None,
         cwd=None,
-        user=None,
-        group=None,
+        runas=None,
         shell=None,
         env=None,
         stateful=False,
@@ -661,12 +668,9 @@ def run(name,
         The current working directory to execute the command in, defaults to
         /root
 
-    user
+    runas
         The user name to run the command as
 
-    group
-        The group context to run the command as
-
     shell
         The shell to use for execution, defaults to the shell grain
 
@@ -787,13 +791,6 @@ def run(name,
            'result': False,
            'comment': ''}
 
-    if cwd and not os.path.isdir(cwd):
-        ret['comment'] = (
-            'Desired working directory "{0}" '
-            'is not available'
-        ).format(cwd)
-        return ret
-
     # Need the check for None here, if env is not provided then it falls back
     # to None and it is assumed that the environment is not being overridden.
     if env is not None and not isinstance(env, (list, dict)):
@@ -801,58 +798,68 @@ def run(name,
                           'documentation.')
         return ret
 
-    if HAS_GRP:
-        pgid = os.getegid()
+    if 'user' in kwargs or 'group' in kwargs:
+        salt.utils.warn_until(
+            'Oxygen',
+            'The legacy user/group arguments are deprecated. '
+            'Replace them with runas. '
+            'These arguments will be removed in Salt Oxygen.'
+        )
+        if 'user' in kwargs and kwargs['user'] is not None and runas is None:
+            runas = kwargs.pop('user')
 
-    cmd_kwargs = {'cwd': cwd,
-                  'runas': user,
-                  'use_vt': use_vt,
-                  'shell': shell or __grains__['shell'],
-                  'env': env,
-                  'umask': umask,
-                  'output_loglevel': output_loglevel,
-                  'quiet': quiet}
+    cmd_kwargs = copy.deepcopy(kwargs)
+    cmd_kwargs.update({'cwd': cwd,
+                       'runas': runas,
+                       'use_vt': use_vt,
+                       'shell': shell or __grains__['shell'],
+                       'env': env,
+                       'umask': umask,
+                       'output_loglevel': output_loglevel,
+                       'quiet': quiet})
 
-    try:
-        cret = mod_run_check(cmd_kwargs, onlyif, unless, group, creates)
-        if isinstance(cret, dict):
-            ret.update(cret)
-            return ret
-
-        if __opts__['test'] and not test_name:
-            ret['result'] = None
-            ret['comment'] = 'Command "{0}" would have been executed'.format(name)
-            return _reinterpreted_state(ret) if stateful else ret
-
-        # Wow, we passed the test, run this sucker!
-        try:
-            cmd_all = __salt__['cmd.run_all'](
-                name, timeout=timeout, python_shell=True, **cmd_kwargs
-            )
-        except CommandExecutionError as err:
-            ret['comment'] = str(err)
-            return ret
-
-        ret['changes'] = cmd_all
-        ret['result'] = not bool(cmd_all['retcode'])
-        ret['comment'] = 'Command "{0}" run'.format(name)
-
-        # Ignore timeout errors if asked (for nohups) and treat cmd as a success
-        if ignore_timeout:
-            trigger = 'Timed out after'
-            if ret['changes'].get('retcode') == 1 and trigger in ret['changes'].get('stdout'):
-                ret['changes']['retcode'] = 0
-                ret['result'] = True
-
-        if stateful:
-            ret = _reinterpreted_state(ret)
-        if __opts__['test'] and cmd_all['retcode'] == 0 and ret['changes']:
-            ret['result'] = None
+    cret = mod_run_check(cmd_kwargs, onlyif, unless, creates)
+    if isinstance(cret, dict):
+        ret.update(cret)
         return ret
 
-    finally:
-        if HAS_GRP:
-            os.setegid(pgid)
+    if __opts__['test'] and not test_name:
+        ret['result'] = None
+        ret['comment'] = 'Command "{0}" would have been executed'.format(name)
+        return _reinterpreted_state(ret) if stateful else ret
+
+    if cwd and not os.path.isdir(cwd):
+        ret['comment'] = (
+            'Desired working directory "{0}" '
+            'is not available'
+        ).format(cwd)
+        return ret
+
+    # Wow, we passed the test, run this sucker!
+    try:
+        cmd_all = __salt__['cmd.run_all'](
+            name, timeout=timeout, python_shell=True, **cmd_kwargs
+        )
+    except CommandExecutionError as err:
+        ret['comment'] = str(err)
+        return ret
+
+    ret['changes'] = cmd_all
+    ret['result'] = not bool(cmd_all['retcode'])
+    ret['comment'] = 'Command "{0}" run'.format(name)
+
+    # Ignore timeout errors if asked (for nohups) and treat cmd as a success
+    if ignore_timeout:
+        trigger = 'Timed out after'
+        if ret['changes'].get('retcode') == 1 and trigger in ret['changes'].get('stdout'):
+            ret['changes']['retcode'] = 0
+            ret['result'] = True
+
+    if stateful:
+        ret = _reinterpreted_state(ret)
+    if __opts__['test'] and cmd_all['retcode'] == 0 and ret['changes']:
+        ret['result'] = None
+    return ret
 
 
 def script(name,
@@ -862,8 +869,7 @@ def script(name,
            unless=None,
            creates=None,
            cwd=None,
-           user=None,
-           group=None,
+           runas=None,
            shell=None,
            env=None,
            stateful=False,
@@ -871,6 +877,8 @@ def script(name,
            timeout=None,
            use_vt=False,
            output_loglevel='debug',
+           defaults=None,
+           context=None,
            **kwargs):
     '''
     Download a script and execute it with specified arguments.
@@ -901,12 +909,9 @@ def script(name,
         The current working directory to execute the command in, defaults to
         /root
 
-    user
+    runas
         The name of the user to run the command as
 
-    group
-        The group context to run the command as
-
     shell
         The shell to use for execution. The default is set in grains['shell']
 
@@ -951,6 +956,9 @@ def script(name,
                 - env:
                   - PATH: {{ [current_path, '/my/special/bin']|join(':') }}
 
+    saltenv : ``base``
+        The Salt environment to use
+
     umask
          The umask (in octal) to use when running the command.
 
@@ -978,6 +986,16 @@ def script(name,
         interactively to the console and the logs.
         This is experimental.
 
+    context
+        .. versionadded:: 2016.3.0
+
+        Overrides default context variables passed to the template.
+
+    defaults
+        .. versionadded:: 2016.3.0
+
+        Default context passed to the template.
+
     output_loglevel
         Control the loglevel at which the output from the command is logged.
         Note that the command being run will still be logged (loglevel: DEBUG)
@@ -997,13 +1015,6 @@ def script(name,
            'result': False,
            'comment': ''}
 
-    if cwd and not os.path.isdir(cwd):
-        ret['comment'] = (
-            'Desired working directory "{0}" '
-            'is not available'
-        ).format(cwd)
-        return ret
-
     # Need the check for None here, if env is not provided then it falls back
     # to None and it is assumed that the environment is not being overridden.
     if env is not None and not isinstance(env, (list, dict)):
@@ -1011,28 +1022,47 @@ def script(name,
                           'documentation.')
         return ret
 
-    if HAS_GRP:
-        pgid = os.getegid()
+    if context and not isinstance(context, dict):
+        ret['comment'] = ('Invalidly-formatted \'context\' parameter. Must '
+                          'be formed as a dict.')
+        return ret
+    if defaults and not isinstance(defaults, dict):
+        ret['comment'] = ('Invalidly-formatted \'defaults\' parameter. Must '
+                          'be formed as a dict.')
+        return ret
+
+    tmpctx = defaults if defaults else {}
+    if context:
+        tmpctx.update(context)
+
+    if 'user' in kwargs or 'group' in kwargs:
+        salt.utils.warn_until(
+            'Oxygen',
+            'The legacy user/group arguments are deprecated. '
+            'Replace them with runas. '
+            'These arguments will be removed in Salt Oxygen.'
+        )
+        if 'user' in kwargs and kwargs['user'] is not None and runas is None:
+            runas = kwargs.pop('user')
 
     cmd_kwargs = copy.deepcopy(kwargs)
-    cmd_kwargs.update({'runas': user,
+    cmd_kwargs.update({'runas': runas,
                        'shell': shell or __grains__['shell'],
                        'env': env,
                        'onlyif': onlyif,
                        'unless': unless,
-                       'user': user,
-                       'group': group,
                        'cwd': cwd,
                        'template': template,
                        'umask': umask,
                        'timeout': timeout,
                        'output_loglevel': output_loglevel,
                        'use_vt': use_vt,
+                       'context': tmpctx,
                        'saltenv': __env__})
 
     run_check_cmd_kwargs = {
         'cwd': cwd,
-        'runas': user,
+        'runas': runas,
         'shell': shell or __grains__['shell']
     }
 
@@ -1044,46 +1074,48 @@ def script(name,
     if len(name.split()) > 1:
         cmd_kwargs.update({'args': name.split(' ', 1)[1]})
 
-    try:
-        cret = mod_run_check(
-            run_check_cmd_kwargs, onlyif, unless, group, creates
-        )
-        if isinstance(cret, dict):
-            ret.update(cret)
-            return ret
-
-        if __opts__['test'] and not test_name:
-            ret['result'] = None
-            ret['comment'] = 'Command {0!r} would have been ' \
-                             'executed'.format(name)
-            return _reinterpreted_state(ret) if stateful else ret
-
-        # Wow, we passed the test, run this sucker!
-        try:
-            cmd_all = __salt__['cmd.script'](source, python_shell=True, **cmd_kwargs)
-        except (CommandExecutionError, SaltRenderError, IOError) as err:
-            ret['comment'] = str(err)
-            return ret
-
-        ret['changes'] = cmd_all
-        if kwargs.get('retcode', False):
-            ret['result'] = not bool(cmd_all)
-        else:
-            ret['result'] = not bool(cmd_all['retcode'])
-        if ret.get('changes', {}).get('cache_error'):
-            ret['comment'] = 'Unable to cache script {0} from saltenv ' \
-                             '{1!r}'.format(source, __env__)
-        else:
-            ret['comment'] = 'Command {0!r} run'.format(name)
-        if stateful:
-            ret = _reinterpreted_state(ret)
-        if __opts__['test'] and cmd_all['retcode'] == 0 and ret['changes']:
-            ret['result'] = None
+    cret = mod_run_check(
+        run_check_cmd_kwargs, onlyif, unless, creates
+    )
+    if isinstance(cret, dict):
+        ret.update(cret)
         return ret
 
-    finally:
-        if HAS_GRP:
-            os.setegid(pgid)
+    if __opts__['test'] and not test_name:
+        ret['result'] = None
+        ret['comment'] = 'Command {0!r} would have been ' \
+                         'executed'.format(name)
+        return _reinterpreted_state(ret) if stateful else ret
+
+    if cwd and not os.path.isdir(cwd):
+        ret['comment'] = (
+            'Desired working directory "{0}" '
+            'is not available'
+        ).format(cwd)
+        return ret
+
+    # Wow, we passed the test, run this sucker!
+    try:
+        cmd_all = __salt__['cmd.script'](source, python_shell=True, **cmd_kwargs)
+    except (CommandExecutionError, SaltRenderError, IOError) as err:
+        ret['comment'] = str(err)
+        return ret
+
+    ret['changes'] = cmd_all
+    if kwargs.get('retcode', False):
+        ret['result'] = not bool(cmd_all)
+    else:
+        ret['result'] = not bool(cmd_all['retcode'])
+    if ret.get('changes', {}).get('cache_error'):
+        ret['comment'] = 'Unable to cache script {0} from saltenv ' \
+                         '{1!r}'.format(source, __env__)
+    else:
+        ret['comment'] = 'Command {0!r} run'.format(name)
+    if stateful:
+        ret = _reinterpreted_state(ret)
+    if __opts__['test'] and cmd_all['retcode'] == 0 and ret['changes']:
+        ret['result'] = None
+    return ret
 
 
 def call(name,
@@ -1140,16 +1172,12 @@ def call(name,
                   'use_vt': use_vt,
                   'output_loglevel': output_loglevel,
                   'umask': kwargs.get('umask')}
-    if HAS_GRP:
-        pgid = os.getegid()
-    try:
-        cret = mod_run_check(cmd_kwargs, onlyif, unless, None, creates)
-        if isinstance(cret, dict):
-            ret.update(cret)
-            return ret
-    finally:
-        if HAS_GRP:
-            os.setegid(pgid)
+
+    cret = mod_run_check(cmd_kwargs, onlyif, unless, creates)
+    if isinstance(cret, dict):
+        ret.update(cret)
+        return ret
+
     if not kws:
         kws = {}
     result = func(*args, **kws)
